@@ -10,7 +10,7 @@ use Mojo::URL;
 use Scalar::Util 'weaken';
 use SQL::Abstract;
 
-has abstract => sub { SQL::Abstract->new(quote_char => '"') };
+has abstract => sub { SQL::Abstract->new(name_sep => '.', quote_char => '"') };
 has [qw(auto_migrate search_path)];
 has database_class  => 'Mojo::Pg::Database';
 has dsn             => 'dbi:Pg:';
@@ -30,7 +30,7 @@ has pubsub => sub {
   return $pubsub;
 };
 
-our $VERSION = '3.01';
+our $VERSION = '3.02';
 
 sub db { $_[0]->database_class->new(dbh => $_[0]->_dequeue, pg => $_[0]) }
 
@@ -127,8 +127,8 @@ Mojo::Pg - Mojolicious ♥ PostgreSQL
 
   # Use SQL::Abstract to generate simple CRUD queries for you
   $db->insert('names', {name => 'Isabel'});
-  say $db->select('names', ['id'], {name => 'Isabel'})->hash->{id};
-  $db->update('names', {name => 'Bel'}, {name => 'Isabel'});
+  my $id = $db->select('names', ['id'], {name => 'Isabel'})->hash->{id};
+  $db->update('names', {name => 'Bel'}, {id => $id});
   $db->delete('names', {name => 'Bel'});
 
   # Insert a few rows in a transaction with SQL and placeholders
@@ -302,7 +302,8 @@ L<Mojo::Pg> implements the following attributes.
   my $abstract = $pg->abstract;
   $pg          = $pg->abstract(SQL::Abstract->new);
 
-L<SQL::Abstract> object used to generate CRUD queries for L<Mojo::Pg::Database>.
+L<SQL::Abstract> object used to generate CRUD queries for L<Mojo::Pg::Database>,
+defaults to setting C<name_sep> to C<.> and C<quote_char> to C<">.
 
   # Generate WHERE clause and bind values
   my($stmt, @bind) = $pg->abstract->where({foo => 'bar', baz => 'yada'});
@@ -500,6 +501,8 @@ In alphabetical order:
 
 =over 2
 
+Christopher Eveland
+
 Dan Book
 
 Flavio Poletti
